Struct scc_trait::Components

source ·
pub struct Components<V> { /* private fields */ }
Strongly connected components.

Implementations

source

impl<V> Components<V>

source

pub fn len(&self) -> usize

Returns the number of strongly connected components.

source

pub fn is_empty(&self) -> bool

Checks if there are no components.

source

pub fn iter(&self) -> impl Iterator<Item = &[V]>

Returns an iterator over the strongly connected components.

source

pub fn vertex_component_index(&self, v: &V) -> Option<usize>
where V: Eq + Hash,

Returns the index of the given vertex’s strongly connected component.

source

pub fn get_by_index(&self, i: usize) -> Option<&[V]>

Returns the component with the given index i.

source

pub fn get(&self, v: &V) -> Option<&[V]>
where V: Eq + Hash,

Return the given vertex’s strongly connected component.

source

pub fn successors(&self, i: usize) -> Option<impl '_ + Iterator<Item = usize>>

source

pub fn is_cyclic(&self, i: usize) -> bool

source

pub fn direct_successors(&self, i: usize) -> Option<HashSet<usize>>

source

pub fn depths(&self) -> Vec<usize>

Returns the depth of each component.

The depth of a component is the maximum of the depth of its predecessors plus 1. A component with no predecessors has depth 0.

source

pub fn predecessors(&self) -> Vec<HashSet<usize>>

source

pub fn order_by_depth(&self) -> Vec<usize>

Order components by depth.

The depth of a component is the maximum of the depth of its predecessors plus 1. A component with no predecessors has depth 0.